@@ -13,14 +13,18 @@ typedef struct
       int server_threads;
       int umask;
       llist_entry *trusted_hosts;
+      llist_entry *unsummarized_metrics;
       int debug_level;
       int should_setuid;
       char *setuid_username;
       char *rrd_rootdir;
       char *carbon_server;
       int carbon_port;
+      char *carbon_protocol;
       int carbon_timeout;
+      char *memcached_parameters;
       char *graphite_prefix;
+      char *graphite_path;
       int scalable_mode;
       int write_rrds;
       int all_trusted;
