@@ -98,7 +98,7 @@ SFLOW_GMETRIC(SFLOW_M_mc_auth_cmds, "mc_auth_cmds", "", GANGLIA_SLOPE_BOTH, "%.2
 SFLOW_GMETRIC(SFLOW_M_mc_auth_errors, "mc_auth_errors", "", GANGLIA_SLOPE_BOTH, "%.2f", "memcache", NULL, "Memcache AUTH Errors" )
 SFLOW_GMETRIC(SFLOW_M_mc_bytes_read, "mc_bytes_read", "", GANGLIA_SLOPE_BOTH, "%.2f", "memcache", NULL, "Memcache Bytes Read" )
 SFLOW_GMETRIC(SFLOW_M_mc_bytes_written, "mc_bytes_written", "", GANGLIA_SLOPE_BOTH, "%.2f", "memcache", NULL, "Memcache Bytes Written" )
-SFLOW_GMETRIC(SFLOW_M_mc_limit_maxbytes, "mc_limit_maxbytes", "", GANGLIA_SLOPE_ZERO, "%u", "memcache", NULL, "Memcache Limit MaxBytes" )
+SFLOW_GMETRIC(SFLOW_M_mc_limit_maxbytes, "mc_limit_maxbytes", "", GANGLIA_SLOPE_ZERO, "%.0f", "memcache", NULL, "Memcache Limit MaxBytes" )
 SFLOW_GMETRIC(SFLOW_M_mc_accepting_conns, "mc_accepting_conns", "", GANGLIA_SLOPE_ZERO, "%u", "memcache", NULL, "Memcache Accepting Connections" )
 SFLOW_GMETRIC(SFLOW_M_mc_listen_disabled_num, "mc_listen_disabled_num", "", GANGLIA_SLOPE_ZERO, "%u", "memcache", NULL, "Memcache Listen Disabled" )
 SFLOW_GMETRIC(SFLOW_M_mc_threads, "mc_threads", "", GANGLIA_SLOPE_ZERO, "%u", "memcache", NULL, "Memcache Threads" )
@@ -111,20 +111,25 @@ SFLOW_GMETRIC(SFLOW_M_mc_cmd_touch, "mc_cmd_touch", "", GANGLIA_SLOPE_BOTH, "%.2
 SFLOW_GMETRIC(SFLOW_M_mc_rejected_conns, "mc_rejected_conns", "", GANGLIA_SLOPE_BOTH, "%.2f", "memcache", NULL, "Memcache Rejected Connections" )
 SFLOW_GMETRIC(SFLOW_M_mc_reclaimed, "mc_reclaimed", "", GANGLIA_SLOPE_BOTH, "%.2f", "memcache", NULL, "Memcache Reclaimed" )
 SFLOW_GMETRIC(SFLOW_M_http_meth_option, "http_meth_option", "", GANGLIA_SLOPE_BOTH, "%.2f", "httpd", NULL, "HTTP Method OPTION" )
-SFLOW_GMETRIC(SFLOW_M_meth_get, "http_meth_get", "", GANGLIA_SLOPE_BOTH, "%.2f", "httpd", NULL, "HTTP Method GET" )
-SFLOW_GMETRIC(SFLOW_M_meth_head, "http_meth_head", "", GANGLIA_SLOPE_BOTH, "%.2f", "httpd", NULL, "HTTP Method HEAD" )
-SFLOW_GMETRIC(SFLOW_M_meth_post, "http_meth_post", "", GANGLIA_SLOPE_BOTH, "%.2f", "httpd", NULL, "HTTP Method POST" )
-SFLOW_GMETRIC(SFLOW_M_meth_put, "http_meth_put", "", GANGLIA_SLOPE_BOTH, "%.2f", "httpd", NULL, "HTTP Method PUT" )
-SFLOW_GMETRIC(SFLOW_M_meth_delete, "http_meth_delete", "", GANGLIA_SLOPE_BOTH, "%.2f", "httpd", NULL, "HTTP Method DELETE" )
-SFLOW_GMETRIC(SFLOW_M_meth_trace, "http_meth_trace", "", GANGLIA_SLOPE_BOTH, "%.2f", "httpd", NULL, "HTTP Method TRACE" )
-SFLOW_GMETRIC(SFLOW_M_meth_connect, "http_meth_connect", "", GANGLIA_SLOPE_BOTH, "%.2f", "httpd", NULL, "HTTP Method CONNECT" )
-SFLOW_GMETRIC(SFLOW_M_meth_other, "http_meth_other", "", GANGLIA_SLOPE_BOTH, "%.2f", "httpd", NULL, "HTTP Method other" )
-SFLOW_GMETRIC(SFLOW_M_status_1XX, "http_status_1XX", "", GANGLIA_SLOPE_BOTH, "%.2f", "httpd", NULL, "HTTP Status 1XX" )
-SFLOW_GMETRIC(SFLOW_M_status_2XX, "http_status_2XX", "", GANGLIA_SLOPE_BOTH, "%.2f", "httpd", NULL, "HTTP Status 2XX" )
-SFLOW_GMETRIC(SFLOW_M_status_3XX, "http_status_3XX", "", GANGLIA_SLOPE_BOTH, "%.2f", "httpd", NULL, "HTTP Status 3XX" )
-SFLOW_GMETRIC(SFLOW_M_status_4XX, "http_status_4XX", "", GANGLIA_SLOPE_BOTH, "%.2f", "httpd", NULL, "HTTP Status 4XX" )
-SFLOW_GMETRIC(SFLOW_M_status_5XX, "http_status_5XX", "", GANGLIA_SLOPE_BOTH, "%.2f", "httpd", NULL, "HTTP Status 5XX" )
-SFLOW_GMETRIC(SFLOW_M_status_other, "http_status_other", "", GANGLIA_SLOPE_BOTH, "%.2f", "httpd", NULL, "HTTP Status other" )
+SFLOW_GMETRIC(SFLOW_M_http_meth_get, "http_meth_get", "", GANGLIA_SLOPE_BOTH, "%.2f", "httpd", NULL, "HTTP Method GET" )
+SFLOW_GMETRIC(SFLOW_M_http_meth_head, "http_meth_head", "", GANGLIA_SLOPE_BOTH, "%.2f", "httpd", NULL, "HTTP Method HEAD" )
+SFLOW_GMETRIC(SFLOW_M_http_meth_post, "http_meth_post", "", GANGLIA_SLOPE_BOTH, "%.2f", "httpd", NULL, "HTTP Method POST" )
+SFLOW_GMETRIC(SFLOW_M_http_meth_put, "http_meth_put", "", GANGLIA_SLOPE_BOTH, "%.2f", "httpd", NULL, "HTTP Method PUT" )
+SFLOW_GMETRIC(SFLOW_M_http_meth_delete, "http_meth_delete", "", GANGLIA_SLOPE_BOTH, "%.2f", "httpd", NULL, "HTTP Method DELETE" )
+SFLOW_GMETRIC(SFLOW_M_http_meth_trace, "http_meth_trace", "", GANGLIA_SLOPE_BOTH, "%.2f", "httpd", NULL, "HTTP Method TRACE" )
+SFLOW_GMETRIC(SFLOW_M_http_meth_connect, "http_meth_connect", "", GANGLIA_SLOPE_BOTH, "%.2f", "httpd", NULL, "HTTP Method CONNECT" )
+SFLOW_GMETRIC(SFLOW_M_http_meth_other, "http_meth_other", "", GANGLIA_SLOPE_BOTH, "%.2f", "httpd", NULL, "HTTP Method other" )
+SFLOW_GMETRIC(SFLOW_M_http_status_1XX, "http_status_1XX", "", GANGLIA_SLOPE_BOTH, "%.2f", "httpd", NULL, "HTTP Status 1XX" )
+SFLOW_GMETRIC(SFLOW_M_http_status_2XX, "http_status_2XX", "", GANGLIA_SLOPE_BOTH, "%.2f", "httpd", NULL, "HTTP Status 2XX" )
+SFLOW_GMETRIC(SFLOW_M_http_status_3XX, "http_status_3XX", "", GANGLIA_SLOPE_BOTH, "%.2f", "httpd", NULL, "HTTP Status 3XX" )
+SFLOW_GMETRIC(SFLOW_M_http_status_4XX, "http_status_4XX", "", GANGLIA_SLOPE_BOTH, "%.2f", "httpd", NULL, "HTTP Status 4XX" )
+SFLOW_GMETRIC(SFLOW_M_http_status_5XX, "http_status_5XX", "", GANGLIA_SLOPE_BOTH, "%.2f", "httpd", NULL, "HTTP Status 5XX" )
+SFLOW_GMETRIC(SFLOW_M_http_status_other, "http_status_other", "", GANGLIA_SLOPE_BOTH, "%.2f", "httpd", NULL, "HTTP Status other" )
+SFLOW_GMETRIC(SFLOW_M_http_workers_active, "http_workers_active", "", GANGLIA_SLOPE_BOTH, "%u", "httpd", NULL, "HTTP Workers Active" )
+SFLOW_GMETRIC(SFLOW_M_http_workers_idle, "http_workers_idle", "", GANGLIA_SLOPE_BOTH, "%u", "httpd", NULL, "HTTP Workers Idle" )
+SFLOW_GMETRIC(SFLOW_M_http_workers_max, "http_workers_max", "", GANGLIA_SLOPE_ZERO, "%u", "httpd", NULL, "HTTP Workers Max" )
+SFLOW_GMETRIC(SFLOW_M_http_workers_req_delayed, "http_workers_req_delayed", "", GANGLIA_SLOPE_BOTH, "%.2f", "httpd", NULL, "HTTP Requests Delayed" )
+SFLOW_GMETRIC(SFLOW_M_http_workers_req_dropped, "http_workers_req_dropped", "", GANGLIA_SLOPE_BOTH, "%.2f", "httpd", NULL, "HTTP Requests Dropped" )
 SFLOW_GMETRIC(SFLOW_M_jvm_hmem_initial, "jvm_hmem_initial", "", GANGLIA_SLOPE_BOTH, "%.2f", "jvm", NULL, "JVM Heap Initial" )
 SFLOW_GMETRIC(SFLOW_M_jvm_hmem_used, "jvm_hmem_used", "", GANGLIA_SLOPE_BOTH, "%.2f", "jvm", NULL, "JVM Heap Used" )
 SFLOW_GMETRIC(SFLOW_M_jvm_hmem_committed, "jvm_hmem_committed", "", GANGLIA_SLOPE_BOTH, "%.2f", "jvm", NULL, "JVM Heap Committed" )
@@ -148,3 +153,13 @@ SFLOW_GMETRIC(SFLOW_M_jvm_vcpu_util, "jvm_vcpu_util", "%", GANGLIA_SLOPE_BOTH, "
 SFLOW_GMETRIC(SFLOW_M_jvm_vmem_total, "jvm_vmem_total", "KB", GANGLIA_SLOPE_ZERO, "%.0f", "jvm", NULL, "JVM Memory Total" )
 SFLOW_GMETRIC(SFLOW_M_jvm_vmem_util, "jvm_vmem_util", "%", GANGLIA_SLOPE_ZERO, "%.2f", "jvm", NULL, "JVM Memory Utilization" )
 SFLOW_GMETRIC(SFLOW_M_jvm_release, "jvm_release", "", GANGLIA_SLOPE_ZERO, "%s", "jvm", NULL, "JVM Release" )
+SFLOW_GMETRIC(SFLOW_M_nvml_gpu_count, "nvml_gpu_count", "", GANGLIA_SLOPE_ZERO, "%u", "nvml", NULL, "NVML GPU Count" )
+SFLOW_GMETRIC(SFLOW_M_nvml_gpu_processes, "nvml_gpu_processes", "", GANGLIA_SLOPE_BOTH, "%u", "nvml", NULL, "NVML GPU Processes" )
+SFLOW_GMETRIC(SFLOW_M_nvml_gpu_time, "nvml_gpu_util", "%", GANGLIA_SLOPE_BOTH, "%.2f", "nvml", NULL, "NVML GPU Utilization" )
+SFLOW_GMETRIC(SFLOW_M_nvml_gpu_rw_time, "nvml_gpu_rw_util", "%", GANGLIA_SLOPE_BOTH, "%.2f", "nvml", NULL, "NVML GPU Mem R/W Utilization" )
+SFLOW_GMETRIC(SFLOW_M_nvml_gpu_mem_total, "nvml_gpu_mem_total", "KB", GANGLIA_SLOPE_ZERO, "%.0f", "nvml", NULL, "NVML GPU Mem Total" )
+SFLOW_GMETRIC(SFLOW_M_nvml_gpu_mem_free, "nvml_gpu_mem_free", "KB", GANGLIA_SLOPE_BOTH, "%.0f", "nvml", NULL, "NVML GPU Mem Free" )
+SFLOW_GMETRIC(SFLOW_M_nvml_gpu_ecc_errors, "nvml_gpu_ecc_errors", "", GANGLIA_SLOPE_BOTH, "%.2f", "nvml", NULL, "NVML GPU ECC Errors" )
+SFLOW_GMETRIC(SFLOW_M_nvml_gpu_energy, "nvml_gpu_power", "W", GANGLIA_SLOPE_BOTH, "%.2f", "nvml", NULL, "NVML GPU Power" )
+SFLOW_GMETRIC(SFLOW_M_nvml_gpu_temperature, "nvml_gpu_temperature", "C", GANGLIA_SLOPE_BOTH, "%u", "nvml", NULL, "NVML GPU Temperature" )
+SFLOW_GMETRIC(SFLOW_M_nvml_gpu_fan_speed, "nvml_gpu_fan_speed", "%", GANGLIA_SLOPE_BOTH, "%u", "nvml", NULL, "NVML GPU Fan Speed" )
