@@ -103,7 +103,8 @@ static cfg_opt_t udp_recv_channel_opts[] = {
   CFG_STR("mcast_if", NULL, CFGF_NONE),
   CFG_SEC("acl", acl_opts, CFGF_NONE), 
   CFG_STR("family", "inet4", CFGF_NONE),
-  CFG_BOOL("retry_bind", cfg_false, CFGF_NONE),
+  CFG_BOOL("retry_bind", cfg_true, CFGF_NONE),
+  CFG_INT("buffer", 0, CFGF_NONE),
   CFG_END()
 };
 
@@ -114,6 +115,7 @@ static cfg_opt_t tcp_accept_channel_opts[] = {
   CFG_SEC("acl", acl_opts, CFGF_NONE),
   CFG_INT("timeout", -1, CFGF_NONE),
   CFG_STR("family", "inet4", CFGF_NONE),
+  CFG_BOOL("gzip_output", 0, CFGF_NONE),
   CFG_END()
 };
 
@@ -704,6 +706,10 @@ ganglia_slope_t cstr_to_slope(const char* str)
         return GANGLIA_SLOPE_BOTH;
     }
     
+    if (!strcmp(str, "derivative")) {
+        return GANGLIA_SLOPE_DERIVATIVE;
+    }
+    
     /*
      * well, it might just be _wrong_ too
      * but we'll handle that situation another time
@@ -727,6 +733,8 @@ const char* slope_to_cstr(unsigned int slope)
         return "negative";
     case GANGLIA_SLOPE_BOTH:
         return "both";
+    case GANGLIA_SLOPE_DERIVATIVE:
+        return "derivative";
     case GANGLIA_SLOPE_UNSPECIFIED:
         return "unspecified";
     }
